@@ -4,7 +4,7 @@ use 5.006;
 use strict;
 use warnings;
 
-our $VERSION = '1.2.21.0';
+our $VERSION = '1.2.25.0';
 
 use Exporter 'import';
 
@@ -31,6 +31,8 @@ use Search::Xapian::BM25Weight;
 use Search::Xapian::BoolWeight;
 use Search::Xapian::TradWeight;
 
+use Search::Xapian::ValueCountMatchSpy;
+
 use Search::Xapian::SimpleStopper;
 use Search::Xapian::PerlStopper;
 
@@ -165,7 +167,7 @@ more 'perlish' interface to some common operations, as demonstrated above.
 
 There are some gaps in the POD documentation for wrapped classes, but you
 can read the Xapian C++ API documentation at
-L<http://xapian.org/docs/apidoc/html/annotated.html> for details of
+L<https://xapian.org/docs/apidoc/html/annotated.html> for details of
 these.  Alternatively, take a look at the code in the examples and tests.
 
 If you want to use Search::Xapian and the threads module together, make
@@ -176,7 +178,7 @@ destroyed more than once.
 
 If you encounter problems, or have any comments, suggestions, patches, etc
 please email the Xapian-discuss mailing list (details of which can be found at
-L<http://xapian.org/lists>).
+L<https://xapian.org/lists>).
 
 =head2 EXPORT
 
@@ -469,7 +471,7 @@ advice, bugfixes, and wrapper code for the more obscure classes.
 Alex Bowley E<lt>kilinrax@cpan.orgE<gt>
 
 Please report any bugs/suggestions to E<lt>xapian-discuss@lists.xapian.orgE<gt>
-or use the Xapian bug tracker L<http://xapian.org/bugs>.  Please do
+or use the Xapian bug tracker L<https://xapian.org/bugs>.  Please do
 NOT use the CPAN bug tracker or mail any of the authors individually.
 
 =head1 LICENSE
@@ -484,6 +486,7 @@ L<Search::Xapian::BoolWeight>,
 L<Search::Xapian::Database>,
 L<Search::Xapian::Document>,
 L<Search::Xapian::Enquire>,
+L<Search::Xapian::MatchSpy>,
 L<Search::Xapian::MultiValueSorter>,
 L<Search::Xapian::PositionIterator>,
 L<Search::Xapian::PostingIterator>,
@@ -496,6 +499,6 @@ L<Search::Xapian::ValueIterator>,
 L<Search::Xapian::Weight>,
 L<Search::Xapian::WritableDatabase>,
 and
-L<http://xapian.org/>.
+L<https://xapian.org/>.
 
 =cut
